@@ -1,17 +1,16 @@
 #ifndef __PY_CLUTTER_H__
 #define __PY_CLUTTER_H__
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 #include <glib.h>
 
 #define NO_IMPORT_PYGOBJECT
 #include <pygobject.h>
 #include <Python.h>
+
 #include <clutter/clutter.h>
-#include <clutter/clutter-feature.h>
+
+#include <cogl/cogl.h>
+#include <cogl/cogl-pango.h>
 
 G_BEGIN_DECLS
 
@@ -25,9 +24,7 @@ void               pyclutter_callback_free   (PyClutterCallback *cb);
 PyObject *         pyclutter_callback_invoke (PyClutterCallback *cb,
                                               ...);
 
-guint32   pyclutter_alpha_func              (ClutterAlpha    *alpha,
-                                             gpointer         data);
-void      pyclutter_effect_complete         (ClutterActor    *actor,
+gdouble   pyclutter_alpha_func              (ClutterAlpha    *alpha,
                                              gpointer         data);
 
 gboolean  pyclutter_geometry_from_pyobject  (PyObject        *object,
@@ -36,6 +33,11 @@ gboolean  pyclutter_color_from_pyobject     (PyObject        *object,
                                              ClutterColor    *color);
 gboolean  pyclutter_actor_box_from_pyobject (PyObject        *object,
                                              ClutterActorBox *box);
+gboolean  pycogl_color_from_pyobject        (PyObject        *object,
+                                             CoglColor       *color);
+PyObject * pycogl_handle_from_handle        (CoglHandle       handle); 
+
+const char * pyclutter_event_get_name       (const ClutterEvent *event);
 
 G_END_DECLS
 
