@@ -12,15 +12,15 @@ def on_stage_add (group, element):
     print 'Adding element: ', element
 
 def on_button_press_event (stage, event):
-    print 'Button press at (x:%d, y:%d): %d' % (event.x, event.y, event.button)
+    print str(event)
     stage.foreach(actor_foreach, 'hello')
     clutter.main_quit()
 
 def main (args):
     stage = clutter.Stage()
     stage.set_size(800,600)
-    stage.set_color(clutter.color_parse('DarkSlateGray'))
-    stage.connect('add', on_stage_add)
+    stage.set_color(clutter.color_from_string('DarkSlateGray'))
+    stage.connect('actor-added', on_stage_add)
     stage.connect('button-press-event', on_button_press_event)
     
     print "stage color: %s" % (stage.get_color())
